pub enum NodeInner {
Const(Const),
Unary(Unary),
Binary(Binary),
Var(Var),
Piecewise(Piecewise),
}Expand description
Concrete varieties of a node which together compose an AST.
Variants
Const(Const)
Some constant value, like a coefficient or offset.
Unary(Unary)
An operation which takes a single operand.
Binary(Binary)
An operation which takes two operands.
Var(Var)
Some unknown value.
Piecewise(Piecewise)
A piecewise function.
Implementations
Sourceimpl NodeInner
impl NodeInner
Sourcepub fn new_const<V: Into<TyValue>>(v: V) -> Self
pub fn new_const<V: Into<TyValue>>(v: V) -> Self
Creates a new constant node with the given value.
Sourcepub fn new_var<S: Into<String>>(ident: S) -> Self
pub fn new_var<S: Into<String>>(ident: S) -> Self
Creates a new variable node with the given identifier.
Sourcepub fn as_const(&self) -> Option<&Const>
pub fn as_const(&self) -> Option<&Const>
Returns a ref to the inner Const if this node is that variant.
Sourcepub fn as_unary(&self) -> Option<&Unary>
pub fn as_unary(&self) -> Option<&Unary>
Returns a ref to the inner Unary if this node is that variant.
Sourcepub fn as_binary(&self) -> Option<&Binary>
pub fn as_binary(&self) -> Option<&Binary>
Returns a ref to the inner Binary if this node is that variant.
Sourcepub fn as_var(&self) -> Option<&Var>
pub fn as_var(&self) -> Option<&Var>
Returns a ref to the inner Var if this node is that variant.
Sourcepub fn pretty_str(&self, parent_precedence: Option<usize>) -> String
pub fn pretty_str(&self, parent_precedence: Option<usize>) -> String
Returns a neatly-formatted string representation of the AST.