pub struct Node { /* private fields */ }Expand description
High-level type representing any node.
Wraps a NodeInner.
Implementations
Methods from Deref<Target = NodeInner>
Sourcepub fn as_const(&self) -> Option<&Const>
pub fn as_const(&self) -> Option<&Const>
Returns a ref to the inner Const if this node is that variant.
Sourcepub fn as_unary(&self) -> Option<&Unary>
pub fn as_unary(&self) -> Option<&Unary>
Returns a ref to the inner Unary if this node is that variant.
Sourcepub fn as_binary(&self) -> Option<&Binary>
pub fn as_binary(&self) -> Option<&Binary>
Returns a ref to the inner Binary if this node is that variant.
Sourcepub fn as_var(&self) -> Option<&Var>
pub fn as_var(&self) -> Option<&Var>
Returns a ref to the inner Var if this node is that variant.
Sourcepub fn pretty_str(&self, parent_precedence: Option<usize>) -> String
pub fn pretty_str(&self, parent_precedence: Option<usize>) -> String
Returns a neatly-formatted string representation of the AST.