pub struct Predicate {
pub op: Option<PredicateOp>,
pub not_op: Option<PredicateOp>,
pub const_value: Option<TyValue>,
pub equivalent: Vec<(Path, Path)>,
pub arity: Option<usize>,
pub children: Vec<Option<Self>>,
}Expand description
Describes a predicate on an AST node.
Fields
op: Option<PredicateOp>Match only on nodes performing the given operation.
not_op: Option<PredicateOp>Match only on nodes which are NOT the given operation.
const_value: Option<TyValue>Match if the node is a constant with some value.
equivalent: Vec<(Path, Path)>Match if the descendant nodes specified by the two paths are equal.
arity: Option<usize>Match if the descendant nodes have a certain number of children.
For piecewise functions, this describes the number of conditional arms.
children: Vec<Option<Self>>Match only on nodes whos children match the given predicates respectively.
A None value in some position means to skip considering the child in that
place, for instance a [None, Some(...)] skips evaluation of a first operand.
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn op(op: PredicateOp) -> Self
pub fn op(op: PredicateOp) -> Self
Creates a predicate matching only on the specified op.