RuleActionSpec

Enum RuleActionSpec 

pub enum RuleActionSpec {
    Replace {
        from: Vec<usize>,
        to: Vec<usize>,
    },
    Swap {
        swap: (Vec<usize>, Vec<usize>),
    },
    Rewrite {
        base: Node,
        replace: Vec<(Vec<usize>, Vec<usize>)>,
        fold: Vec<Vec<usize>>,
    },
    Multi(Vec<Self>),
}
Describes the action to perform when a rule matches.

Variants



Replace

Overwrite a part of the AST with a node elsewhere in the AST.

Fields

from: Vec<usize>

The indexing sequence to fetch the node to be written.

See AstNode::get for more details on indexing.

to: Vec<usize>

The indexing sequence the node should be written to.

See AstNode::get for more details on indexing.



Swap

Swaps two nodes in the AST.

Fields

swap: (Vec<usize>, Vec<usize>)


Rewrite

Constructs a replacement node by starting from some base and performing actions against it from the original node.

Fields

base: Node
replace: Vec<(Vec<usize>, Vec<usize>)>
fold: Vec<Vec<usize>>


Multi(Vec<Self>)

Perform multiple actions in order.

Implementations

Source

impl RuleActionSpec

pub fn apply<N: AstNode + From<Node>>(&self, n: &mut N) -> Result<(), ()>

Applies the action to the given node.