pub struct MetaSpec {
pub is_simplify: bool,
pub alt_form: bool,
}Expand description
Describes metadata about a rule.
Fields
is_simplify: boolalt_form: boolIndicates that the rule describes an equivalence that isn’t necessarily a simplification, but might be a relevant form for algebraic transformations.